==> ui-1.9.1-sources.jar: nanorep/nanowidget/DataClass/NRResult.java <==
package nanorep.nanowidget.DataClass;


import com.nanorep.nanoclient.Interfaces.NRQueryResult;

import java.util.Map;

import nanorep.nanowidget.Components.NRResultItem;

/**
 * Created by nissimpardo on 04/06/16.
 */
public class NRResult {
    private Map<String, Object> params;
    private NRQueryResult mFetchedResult;
    private boolean mIsUnfolded = false;
    private NRResultItem.RowType mRowType;
    private int mHeight;
    private boolean mIsSingle;

    public NRResult(NRQueryResult result, NRResultItem.RowType rowType) {
        mFetchedResult = result;
        mRowType = rowType;
    }

    public Map<String, Object> getParams() {
        return params;
    }

    public NRResult(Map<String, Object> params) {
        this.params = params;
    }

    public NRQueryResult getFetchedResult() {
        return mFetchedResult;
    }

    public void setFetchedResult(NRQueryResult fetchedResult) {
        mFetchedResult = fetchedResult;
    }

    public boolean isUnfolded() {
        return mIsUnfolded;
    }

    public void setUnfolded(boolean unfolded) {
        mIsUnfolded = unfolded;
    }

    public NRResultItem.RowType getRowType() {
        return mRowType;
    }

    public void setRowType(NRResultItem.RowType rowType) {
        mRowType = rowType;
    }

    public int getHeight() {
        return mHeight;
    }

    public void setHeight(int height) {
        mHeight = height;
    }

    public boolean isSingle() {
        return mIsSingle;
    }

    public void setSingle(boolean single) {
        mIsSingle = single;
    }

}

==> ui-2.0.2-sources.jar: nanorep/nanowidget/DataClass/NRResult.java <==
package nanorep.nanowidget.DataClass;


import com.nanorep.nanoclient.Interfaces.NRQueryResult;

import java.util.Map;

/**
 * Created by nissimpardo on 04/06/16.
 */
public class NRResult {
    private Map<String, Object> params;
    private NRQueryResult mFetchedResult;
    private boolean mIsUnfolded = false;
    private RowType mRowType;
    private int mHeight;
    private boolean mIsSingle;

    public enum RowType {
        TITLE, CONTENT, LIKE, CHANNELING
    }

    public NRResult(NRQueryResult result, RowType rowType) {
        mFetchedResult = result;
        mRowType = RowType.TITLE;
    }

    public Map<String, Object> getParams() {
        return params;
    }

    public NRResult(Map<String, Object> params) {
        this.params = params;
    }

    public NRQueryResult getFetchedResult() {
        return mFetchedResult;
    }

    public void setFetchedResult(NRQueryResult fetchedResult) {
        mFetchedResult = fetchedResult;
    }

    public boolean isUnfolded() {
        return mIsUnfolded;
    }

    public void setUnfolded(boolean unfolded) {
        mIsUnfolded = unfolded;
    }

    public RowType getRowType() {
        return mRowType;
    }

    public void setRowType(RowType rowType) {
        mRowType = rowType;
    }

    public int getHeight() {
        return mHeight;
    }

    public void setHeight(int height) {
        mHeight = height;
    }

    public boolean isSingle() {
        return mIsSingle;
    }

    public void setSingle(boolean single) {
        mIsSingle = single;
    }

}
